@@ -1,4 +1,4 @@
-/* 
+/*
  * e-cell-float.c - Float item for e-table.
  * Copyright 2001, CodeFactory AB
  * Copyright 2001, Mikael Hallendal <micke@codefactory.se>
@@ -90,4 +90,4 @@ e_cell_float_new (const char *fontname, GtkJustification justify)
 	return (ECell *) ecn;
 }
 
-E_MAKE_TYPE(e_cell_float, "ECellFloat", ECellFloat, e_cell_float_class_init, e_cell_float_init, PARENT_TYPE)
+E_MAKE_TYPE(e_cell_float, "ECellFloat", ECellFloat, e_cell_float_class_init, e_cell_float_init, PARENT_TYPE);
