@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-without.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -157,10 +157,10 @@ etw_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *etm, int model_r
 
 	/* i is View row */
 	if (model_row != etss->n_map) {
-		for (i = 0; i < etss->n_map; i++) {
-			if (etss->map_table[i] > model_row)
-				etss->map_table[i] += count;
-		}
+	for (i = 0; i < etss->n_map; i++) {
+		if (etss->map_table[i] > model_row)
+			etss->map_table[i] += count;
+	}
 		shift = TRUE;
 	}
 
@@ -248,7 +248,7 @@ etw_init (ETableWithout *etw)
 	etw->priv->free_duplicated_key_func = NULL;
 }
 
-E_MAKE_TYPE(e_table_without, "ETableWithout", ETableWithout, etw_class_init, etw_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_without, "ETableWithout", ETableWithout, etw_class_init, etw_init, PARENT_TYPE);
 
 ETableModel *
 e_table_without_construct (ETableWithout                 *etw,
