@@ -26,7 +26,9 @@
 #include "e-bit-array.h"
 #include "gal/util/e-util.h"
 
-#define PARENT_TYPE G_TYPE_OBJECT
+#define EBA_CLASS(e) ((EBitArrayClass *)((GtkObject *)e)->klass)
+
+#define PARENT_TYPE (gtk_object_get_type ())
 
 #define ONES ((guint32) 0xffffffff)
 
@@ -36,7 +38,7 @@
 #define BITMASK_LEFT(n) ((((n) % 32) == 0) ? 0 : (ONES << (32 - ((n) % 32))))
 #define BITMASK_RIGHT(n) ((guint32)(((guint32) ONES) >> ((n) % 32)))
 
-static GObjectClass *parent_class;
+static GtkObjectClass *parent_class;
 
 static void
 e_bit_array_insert_real(EBitArray *eba, int row)
@@ -46,7 +48,7 @@ e_bit_array_insert_real(EBitArray *eba, int row)
 	if(eba->bit_count >= 0) {
 		/* Add another word if needed. */
 		if ((eba->bit_count & 0x1f) == 0) {
-			eba->data = g_renew(guint32, eba->data, (eba->bit_count >> 5) + 1);
+			eba->data = g_renew(gint, eba->data, (eba->bit_count >> 5) + 1);
 			eba->data[eba->bit_count >> 5] = 0;
 		}
 
@@ -95,10 +97,10 @@ e_bit_array_delete_real(EBitArray *eba, int row, gboolean move_selection_mode)
 		eba->bit_count --;
 		/* Remove the last word if not needed. */
 		if ((eba->bit_count & 0x1f) == 0) {
-			eba->data = g_renew(guint32, eba->data, eba->bit_count >> 5);
+			eba->data = g_renew(gint, eba->data, eba->bit_count >> 5);
 		}
-		if (move_selection_mode && selected && eba->bit_count > 0) {
-			e_bit_array_select_single_row (eba, row == eba->bit_count ? row - 1 : row);
+		if (move_selection_mode && selected) {
+			e_bit_array_select_single_row (eba, row > 0 ? row - 1 : 0);
 		}
 	}
 }
@@ -139,18 +141,17 @@ e_bit_array_move_row(EBitArray *eba, int old_row, int new_row)
 }
 
 static void
-eba_dispose (GObject *object)
+eba_destroy (GtkObject *object)
 {
 	EBitArray *eba;
 
 	eba = E_BIT_ARRAY (object);
 
-	if (eba->data)
-		g_free(eba->data);
+	g_free(eba->data);
 	eba->data = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		(* G_OBJECT_CLASS (parent_class)->dispose) (object);
+	if (GTK_OBJECT_CLASS (parent_class)->destroy)
+		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 /** 
@@ -266,7 +267,7 @@ e_bit_array_select_all (EBitArray *eba)
 	int i;
 	
 	if (!eba->data)
-		eba->data = g_new0 (guint32, (eba->bit_count + 31) / 32);
+		eba->data = g_new0 (gint, (eba->bit_count + 31) / 32);
 	
 	for (i = 0; i < (eba->bit_count + 31) / 32; i ++) {
 		eba->data[i] = ONES;
@@ -298,7 +299,7 @@ e_bit_array_invert_selection (EBitArray *eba)
 	int i;
 
 	if (!eba->data)
-		eba->data = g_new0 (guint32, (eba->bit_count + 31) / 32);
+		eba->data = g_new0 (gint, (eba->bit_count + 31) / 32);
 	
 	for (i = 0; i < (eba->bit_count + 31) / 32; i ++) {
 		eba->data[i] = ~eba->data[i];
@@ -379,7 +380,7 @@ e_bit_array_select_single_row (EBitArray *eba, int row)
 		if (!((i == BOX(row) && eba->data[i] == BITMASK(row)) ||
 		      (i != BOX(row) && eba->data[i] == 0))) {
 			g_free(eba->data);
-			eba->data = g_new0(guint32, (eba->bit_count + 31) / 32);
+			eba->data = g_new0(gint, (eba->bit_count + 31) / 32);
 			eba->data[BOX(row)] = BITMASK(row);
 
 			break;
@@ -407,23 +408,23 @@ e_bit_array_init (EBitArray *eba)
 static void
 e_bit_array_class_init (EBitArrayClass *klass)
 {
-	GObjectClass *object_class;
+	GtkObjectClass *object_class;
 
-	parent_class = g_type_class_ref (PARENT_TYPE);
+	parent_class = gtk_type_class (PARENT_TYPE);
 
-	object_class = G_OBJECT_CLASS(klass);
+	object_class = GTK_OBJECT_CLASS(klass);
 
-	object_class->dispose = eba_dispose;
+	object_class->destroy = eba_destroy;
 }
 
 E_MAKE_TYPE(e_bit_array, "EBitArray", EBitArray,
-	    e_bit_array_class_init, e_bit_array_init, PARENT_TYPE)
+	    e_bit_array_class_init, e_bit_array_init, PARENT_TYPE);
 
 EBitArray *
 e_bit_array_new (int count)
 {
-	EBitArray *eba = g_object_new (E_BIT_ARRAY_TYPE, NULL);
+	EBitArray *eba = gtk_type_new (e_bit_array_get_type ());
 	eba->bit_count = count;
-	eba->data = g_new0(guint32, (eba->bit_count + 31) / 32);
+	eba->data = g_new0(gint, (eba->bit_count + 31) / 32);
 	return eba;
 }
