@@ -44,7 +44,7 @@
 #define COLOR_PREVIEW_HEIGHT 15
 
 enum {
-	COLOR_CHANGED,
+	CHANGED,
 	LAST_SIGNAL
 };
 
@@ -53,44 +53,29 @@ struct _ColorNamePair {
 	char *name;	/* english name - eg. "white" */
 };
 
-static guint color_palette_signals [LAST_SIGNAL] = { 0, };
+static gint color_palette_signals [LAST_SIGNAL] = { 0, };
 
-#define PARENT_TYPE GTK_TYPE_VBOX
 static GObjectClass *color_palette_parent_class;
 
 #define make_color(P,COL) (((COL) != NULL) ? (COL) : ((P) ? ((P)->default_color) : NULL))
 
-static void
-color_palette_destroy (GtkObject *object)
-{
-	ColorPalette *P = COLOR_PALETTE (object);
-	GtkObjectClass *klass = (GtkObjectClass *)color_palette_parent_class;
-
-	if (P->tool_tip) {
-		g_object_unref (P->tool_tip);
-		P->tool_tip = NULL;
-	}
-
-	if (P->current_color) {
-		gdk_color_free (P->current_color);
-		P->current_color = NULL;
-	}
-	
-	color_palette_set_group (P, NULL);
-
-	memset (P->items, 0, P->total * sizeof (GnomeCanvasItem *));
-
-	if (klass->destroy)
-                klass->destroy (object);
-}
-
 static void
 color_palette_finalize (GObject *object)
 {
 	ColorPalette *P = COLOR_PALETTE (object);
 
+	if (P->tool_tip) {
+		gtk_object_unref (GTK_OBJECT (P->tool_tip));
+		P->tool_tip = NULL;
+	}
+
 	g_free (P->items);
 
+	if (P->current_color)
+		gdk_color_free (P->current_color);
+	
+	color_palette_set_group (P, NULL);
+
 	(*color_palette_parent_class->finalize) (object);
 }
 
@@ -98,47 +83,67 @@ static void
 color_palette_class_init (GObjectClass *object_class)
 {
 	object_class->finalize = color_palette_finalize;
-	((GtkObjectClass *)object_class)->destroy = color_palette_destroy;
 
 	color_palette_parent_class = g_type_class_peek_parent (object_class);
 
-	color_palette_signals [COLOR_CHANGED] =
-		g_signal_new ("color_changed",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ColorPaletteClass, color_changed),
-			      NULL, NULL,
-			      e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN_BOOLEAN,
-			      G_TYPE_NONE, 4, G_TYPE_POINTER,
-			      G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+	color_palette_signals [CHANGED] =
+		gtk_signal_new (
+			"changed",
+			GTK_RUN_LAST,
+			E_OBJECT_CLASS_TYPE (object_class),
+			GTK_SIGNAL_OFFSET (ColorPaletteClass, changed),
+			e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN,
+			GTK_TYPE_NONE, 3, GTK_TYPE_POINTER,
+			GTK_TYPE_BOOL, GTK_TYPE_BOOL);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, color_palette_signals, LAST_SIGNAL);
 }
 
-E_MAKE_TYPE (color_palette,
-	     "ColorPalette",
-	     ColorPalette,
-	     color_palette_class_init,
-	     NULL,
-	     PARENT_TYPE)
-
-static void
-emit_color_changed (ColorPalette *P, GdkColor *color,
-		    gboolean custom, gboolean by_user, gboolean is_default)
+GtkType
+color_palette_get_type (void)
 {
-	GdkColor *new = make_color (P, color);
+	static GtkType type = 0;
 
-	if (new != NULL)
-		new = gdk_color_copy (new);
+	if (!type){
+		GtkTypeInfo info = {
+			"ColorPalette",
+			sizeof (ColorPalette),
+			sizeof (ColorPaletteClass),
+			(GtkClassInitFunc) color_palette_class_init,
+			(GtkObjectInitFunc) NULL,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		type = gtk_type_unique (gtk_vbox_get_type (), &info);
+	}
+
+	return type;
+}
+
+/*
+ * Fires signal "changed" with color as its param
+ *
+ * prop
+ */
+static void
+emit_change (ColorPalette *P, GdkColor *color, gboolean custom, gboolean by_user)
+{
+	GdkColor *new;
+	
+	/* Set it as current color */
 	if (P->current_color)
 		gdk_color_free (P->current_color);
-	P->current_color = new;
-	P->current_is_default = is_default;
+	new = make_color (P, color);
+	P->current_color = new ? gdk_color_copy (new) : NULL;
 
 	/* Only add custom colors to the group */
 	if (custom && color)
 		color_group_add_color (P->color_group, color);
 	
-	g_signal_emit (P, color_palette_signals [COLOR_CHANGED], 0,
-		       color, custom, by_user, is_default);
+	gtk_signal_emit (
+		GTK_OBJECT (P), color_palette_signals [CHANGED], color, custom, by_user);
 }
 
 
@@ -166,8 +171,8 @@ color_palette_change_custom_color (ColorPalette *P, GdkColor const * const new)
 	for (index = P->custom_color_pos; index < P->total - 1; index++) {
 		GdkColor *color;
 		GdkColor *outline;
-		item = P->items[index];
-		next_item = P->items[index + 1];
+		item = P->items [index];
+		next_item = P->items [index + 1];
 
 		g_object_get (G_OBJECT (next_item),
 			"fill_color_gdk",	&color,
@@ -180,7 +185,7 @@ color_palette_change_custom_color (ColorPalette *P, GdkColor const * const new)
 		gdk_color_free (color);
 		gdk_color_free (outline);
 	}
-	item = P->items[index];
+	item = P->items [index];
 	gnome_canvas_item_set (item,
 			       "fill_color_gdk", new,
 			       "outline_color_gdk", new,
@@ -190,6 +195,7 @@ color_palette_change_custom_color (ColorPalette *P, GdkColor const * const new)
 				    new->green,
 				    new->blue,
 				    0);
+	return;
 }
 
 /*
@@ -207,13 +213,17 @@ cust_color_set (GtkWidget  *color_picker, guint r, guint g, guint b, guint a,
 	c_color.blue  = (gushort)b;
 
 	e_color_alloc_gdk (NULL, &c_color);
-	emit_color_changed (P, &c_color, TRUE, TRUE, FALSE);
+	emit_change (P, &c_color, TRUE, TRUE);
 }
 
+/*
+ * NoColour/Auto button was pressed.
+ * emit a signal with 'NULL' color.
+ */
 static void
-cb_default_clicked (GtkWidget *button, ColorPalette *P)
+cb_nocolor_clicked (GtkWidget *button, ColorPalette *P)
 {
-	emit_color_changed (P, P->default_color, FALSE, TRUE, TRUE);
+        emit_change (P, P->default_color, FALSE, TRUE);
 }
 
 /*
@@ -227,13 +237,14 @@ color_clicked (GtkWidget *button, ColorPalette *P)
 	GdkColor        *gdk_color;
 
 	index = GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (button)));
-	item  = P->items[index];
+	item  = P->items [index];
 
-	g_object_get (item,
-		      "fill_color_gdk", &gdk_color,
-		      NULL);
+	gtk_object_get (
+		GTK_OBJECT (item),
+		"fill_color_gdk", &gdk_color,
+		NULL);
 
-	emit_color_changed (P, gdk_color, FALSE, TRUE, FALSE);
+	emit_change (P, gdk_color, FALSE, TRUE);
 
 	gdk_color_free (gdk_color);
 }
@@ -318,8 +329,8 @@ color_palette_button_new(ColorPalette *P, GtkTable* table,
 	gtk_table_attach (table, button,
 			  col, col+1, row, row+1, GTK_FILL, GTK_FILL, 1, 1);
 
-	g_signal_connect (button, "clicked",
-			  G_CALLBACK (color_clicked), P);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+			    GTK_SIGNAL_FUNC(color_clicked), P);
 	gtk_object_set_user_data (GTK_OBJECT (button),
 				  GINT_TO_POINTER (data));
 	return item;
@@ -356,7 +367,7 @@ color_palette_setup (ColorPalette *P,
 		     int ncols, int nrows,
 		     ColorNamePair *color_names)
 {
-	GtkWidget *default_button;
+	GtkWidget *nocolor_button;
 	GtkWidget *cust_label;
 	GtkWidget *table;
 	GtkTooltips *tool_tip;
@@ -364,17 +375,18 @@ color_palette_setup (ColorPalette *P,
 
 	table = gtk_table_new (ncols, nrows, FALSE);
 
-	if (no_color_label != NULL) {
-		default_button = gtk_button_new_with_label (no_color_label);
 
-		gtk_table_attach (GTK_TABLE (table), default_button,
+	if (no_color_label != NULL) {
+		nocolor_button = gtk_button_new_with_label (no_color_label);
+
+		gtk_table_attach (GTK_TABLE (table), nocolor_button,
 				  0, ncols, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
-		g_signal_connect (default_button, "clicked",
-				  G_CALLBACK (cb_default_clicked), P);
+		gtk_signal_connect (GTK_OBJECT (nocolor_button), "clicked",
+				    GTK_SIGNAL_FUNC(cb_nocolor_clicked), P);
 	}
 
-	P->tool_tip = tool_tip = gtk_tooltips_new ();
-	g_object_ref (P->tool_tip);
+	P->tool_tip = tool_tip = gtk_tooltips_new();
+	gtk_object_ref (GTK_OBJECT (P->tool_tip));
 	gtk_object_sink (GTK_OBJECT (P->tool_tip));
 
 	P->custom_color_pos = -1;
@@ -416,7 +428,7 @@ color_palette_setup (ColorPalette *P,
 				break;
 			}
 
-			P->items[total] =
+			P->items [total] =
 				color_palette_button_new (
 					P,
 					GTK_TABLE (table),
@@ -443,43 +455,26 @@ color_palette_setup (ColorPalette *P,
 	gnome_color_picker_set_title (P->picker, _("Choose Custom Color"));
 	gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (P->picker), ncols - 3, ncols,
 			  row + 1, row + 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
-	g_signal_connect (P->picker, "color_set",
-			  G_CALLBACK (cust_color_set), P);
+	gtk_signal_connect (GTK_OBJECT (P->picker), "color_set",
+			    GTK_SIGNAL_FUNC (cust_color_set), P);
 	return table;
 }
 
-void
-color_palette_set_color_to_default (ColorPalette *P)
-{
-	g_return_if_fail (P != NULL);
-	g_return_if_fail (IS_COLOR_GROUP (P->color_group));
-
-	emit_color_changed (P, P->default_color, FALSE, TRUE, TRUE);
-}
-
 void
 color_palette_set_current_color (ColorPalette *P, GdkColor *color)
 {
 	g_return_if_fail (P != NULL);
 	g_return_if_fail (IS_COLOR_GROUP (P->color_group));
 
-	if (color)
-		emit_color_changed
-			(P, color, color_in_palette (P->default_set, color),
-			 FALSE, FALSE);
-	else
-		color_palette_set_color_to_default (P);
+	emit_change (P, color, color_in_palette (P->default_set, color), FALSE);
 }
 
 GdkColor *
-color_palette_get_current_color (ColorPalette *P, gboolean *is_default)
+color_palette_get_current_color(ColorPalette *P)
 {
 	g_return_val_if_fail (P != NULL, NULL);
 	g_return_val_if_fail (IS_COLOR_GROUP (P->color_group), NULL);
 
-	if (is_default != NULL)
-		*is_default = P->current_is_default;
-
 	return P->current_color ? gdk_color_copy (P->current_color) : NULL;
 }
 
@@ -532,12 +527,11 @@ color_palette_new_with_vals (char const * const no_color_label,
 
 	g_return_val_if_fail (color_names != NULL, NULL);
 
-	P = g_object_new (COLOR_PALETTE_TYPE, NULL);
+	P = gtk_type_new (color_palette_get_type ());
 
 	P->default_set   = color_names;
 	P->default_color = default_color;
 	P->current_color = default_color ? gdk_color_copy (default_color) : NULL;
-	P->current_is_default = TRUE;
 	color_palette_set_group (P, cg);
 
 	color_palette_construct (P, no_color_label, ncols, nrows);
