@@ -30,12 +30,8 @@
 
 #include <config.h>
 
-#include <gal/util/e-util.h>
-#include <gal/util/e-i18n.h>
-
 #include <gtk/gtksignal.h>
 #include <gtk/gtkviewport.h>
-#include <gtk/gtktypebuiltins.h>
 
 #include "e-vscrollbar.h"
 #include "e-hscrollbar.h"
@@ -80,14 +76,14 @@
 
 /* Object argument IDs */
 enum {
-	PROP_0,
-	PROP_HADJUSTMENT,
-	PROP_VADJUSTMENT,
-	PROP_HSCROLLBAR_POLICY,
-	PROP_VSCROLLBAR_POLICY,
-	PROP_FRAME_PLACEMENT,
-	PROP_SHADOW_TYPE,
-	PROP_SCROLLBAR_SPACING
+	ARG_0,
+	ARG_HADJUSTMENT,
+	ARG_VADJUSTMENT,
+	ARG_HSCROLLBAR_POLICY,
+	ARG_VSCROLLBAR_POLICY,
+	ARG_FRAME_PLACEMENT,
+	ARG_SHADOW_TYPE,
+	ARG_SCROLLBAR_SPACING
 };
 
 /* Private part of the EScrollFrame structure */
@@ -123,9 +119,9 @@ typedef struct {
 
 static void e_scroll_frame_class_init (EScrollFrameClass *class);
 static void e_scroll_frame_init (EScrollFrame *sf);
-static void e_scroll_frame_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
-static void e_scroll_frame_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
-static void e_scroll_frame_dispose (GObject *object);
+static void e_scroll_frame_set_arg (GtkObject *object, GtkArg *arg, guint arg_id);
+static void e_scroll_frame_get_arg (GtkObject *object, GtkArg *arg, guint arg_id);
+static void e_scroll_frame_destroy (GtkObject *object);
 static void e_scroll_frame_finalize (GObject *object);
 
 static void e_scroll_frame_map (GtkWidget *widget);
@@ -139,7 +135,6 @@ static void e_scroll_frame_remove (GtkContainer *container, GtkWidget *widget);
 static void e_scroll_frame_forall (GtkContainer *container, gboolean include_internals,
 				     GtkCallback callback, gpointer callback_data);
 
-#define PARENT_TYPE GTK_TYPE_BIN
 static GtkBinClass *parent_class;
 
 
@@ -152,31 +147,76 @@ static GtkBinClass *parent_class;
  *
  * Return value: The type ID of the #EScrollFrame class.
  **/
-E_MAKE_TYPE (e_scroll_frame,
-	     "EScrollFrame",
-	     EScrollFrame,
-	     e_scroll_frame_class_init,
-	     e_scroll_frame_init,
-	     PARENT_TYPE)
+GtkType
+e_scroll_frame_get_type (void)
+{
+	static GtkType scroll_frame_type = 0;
+
+	if (!scroll_frame_type) {
+		static const GtkTypeInfo scroll_frame_info = {
+			"EScrollFrame",
+			sizeof (EScrollFrame),
+			sizeof (EScrollFrameClass),
+			(GtkClassInitFunc) e_scroll_frame_class_init,
+			(GtkObjectInitFunc) e_scroll_frame_init,
+			NULL, /* reserved_1 */
+			NULL, /* reserved_2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		scroll_frame_type = gtk_type_unique (GTK_TYPE_BIN, &scroll_frame_info);
+	}
+
+	return scroll_frame_type;
+}
 
 /* Class initialization function for the scroll frame widget */
 static void
 e_scroll_frame_class_init (EScrollFrameClass *class)
 {
-	GObjectClass *object_class;
+	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	GtkContainerClass *container_class;
 
-	object_class = (GObjectClass *) class;
+	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 	container_class = (GtkContainerClass *) class;
 
-	parent_class = g_type_class_ref (PARENT_TYPE);
+	parent_class = gtk_type_class (GTK_TYPE_BIN);
 
-	object_class->set_property = e_scroll_frame_set_property;
-	object_class->get_property = e_scroll_frame_get_property;
-	object_class->dispose = e_scroll_frame_dispose;
-	object_class->finalize = e_scroll_frame_finalize;
+	gtk_object_add_arg_type ("EScrollFrame::hadjustment",
+				 GTK_TYPE_ADJUSTMENT,
+				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
+				 ARG_HADJUSTMENT);
+	gtk_object_add_arg_type ("EScrollFrame::vadjustment",
+				 GTK_TYPE_ADJUSTMENT,
+				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
+				 ARG_VADJUSTMENT);
+	gtk_object_add_arg_type ("EScrollFrame::hscrollbar_policy",
+				 GTK_TYPE_POLICY_TYPE,
+				 GTK_ARG_READWRITE,
+				 ARG_HSCROLLBAR_POLICY);
+	gtk_object_add_arg_type ("EScrollFrame::vscrollbar_policy",
+				 GTK_TYPE_POLICY_TYPE,
+				 GTK_ARG_READWRITE,
+				 ARG_VSCROLLBAR_POLICY);
+	gtk_object_add_arg_type ("EScrollFrame::frame_placement",
+				 GTK_TYPE_CORNER_TYPE,
+				 GTK_ARG_READWRITE,
+				 ARG_FRAME_PLACEMENT);
+	gtk_object_add_arg_type ("EScrollFrame::shadow_type",
+				 GTK_TYPE_SHADOW_TYPE,
+				 GTK_ARG_READWRITE,
+				 ARG_SHADOW_TYPE);
+	gtk_object_add_arg_type ("EScrollFrame::scrollbar_spacing",
+				 GTK_TYPE_UINT,
+				 GTK_ARG_READWRITE,
+				 ARG_SCROLLBAR_SPACING);
+
+	object_class->set_arg = e_scroll_frame_set_arg;
+	object_class->get_arg = e_scroll_frame_get_arg;
+	object_class->destroy = e_scroll_frame_destroy;
+	G_OBJECT_CLASS (object_class)->finalize = e_scroll_frame_finalize;
 
 	widget_class->map = e_scroll_frame_map;
 	widget_class->unmap = e_scroll_frame_unmap;
@@ -188,55 +228,6 @@ e_scroll_frame_class_init (EScrollFrameClass *class)
 	container_class->add = e_scroll_frame_add;
 	container_class->remove = e_scroll_frame_remove;
 	container_class->forall = e_scroll_frame_forall;
-
-	g_object_class_install_property (object_class, PROP_HADJUSTMENT,
-					 g_param_spec_object ("hadjustment",
-							      _( "HAdjustment" ),
-							      _( "HAdjustment" ),
-							      GTK_TYPE_ADJUSTMENT,
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-
-	g_object_class_install_property (object_class, PROP_VADJUSTMENT,
-					 g_param_spec_object ("vadjustment",
-							      _( "VAdjustment" ),
-							      _( "VAdjustment" ),
-							      GTK_TYPE_ADJUSTMENT,
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-
-	g_object_class_install_property (object_class, PROP_HSCROLLBAR_POLICY,
-					 g_param_spec_enum ("hscrollbar_policy",
-							    _( "hscrollbar policy" ),
-							    _( "hscrollbar policy" ),
-							    GTK_TYPE_POLICY_TYPE, GTK_POLICY_AUTOMATIC,
-							    G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_VSCROLLBAR_POLICY,
-					 g_param_spec_enum ("vscrollbar_policy",
-							    _( "vscrollbar policy" ),
-							    _( "vscrollbar policy" ),
-							    GTK_TYPE_POLICY_TYPE, GTK_POLICY_AUTOMATIC,
-							    G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_FRAME_PLACEMENT,
-					 g_param_spec_enum ("frame_placement",
-							    _( "Frame placement" ),
-							    _( "Frame placement" ),
-							    GTK_TYPE_CORNER_TYPE, GTK_CORNER_TOP_LEFT,
-							    G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_SHADOW_TYPE,
-					 g_param_spec_enum ("shadow_type",
-							    _( "Shadow type" ),
-							    _( "Shadow type" ),
-							    GTK_TYPE_SHADOW_TYPE, GTK_CORNER_TOP_LEFT,
-							    G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_SHADOW_TYPE,
-					 g_param_spec_uint ("scrollbar_spacing",
-							    _( "Scrollbar spacing" ),
-							    _( "Scrollbar spacing" ),
-							    0, G_MAXUINT, 0,
-							    G_PARAM_READWRITE));
 }
 
 /* Object initialization function for the scroll frame widget */
@@ -261,7 +252,7 @@ e_scroll_frame_init (EScrollFrame *sf)
 
 /* Set_arg handler for the scroll frame widget */
 static void
-e_scroll_frame_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+e_scroll_frame_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	EScrollFrame *sf;
 	ScrollFramePrivate *priv;
@@ -269,33 +260,33 @@ e_scroll_frame_set_property (GObject *object, guint prop_id, const GValue *value
 	sf = E_SCROLL_FRAME (object);
 	priv = sf->priv;
 
-	switch (prop_id) {
-	case PROP_HADJUSTMENT:
-		e_scroll_frame_set_hadjustment (sf, g_value_get_object (value));
+	switch (arg_id) {
+	case ARG_HADJUSTMENT:
+		e_scroll_frame_set_hadjustment (sf, GTK_VALUE_POINTER (*arg));
 		break;
 
-	case PROP_VADJUSTMENT:
-		e_scroll_frame_set_vadjustment (sf, g_value_get_object (value));
+	case ARG_VADJUSTMENT:
+		e_scroll_frame_set_vadjustment (sf, GTK_VALUE_POINTER (*arg));
 		break;
 
-	case PROP_HSCROLLBAR_POLICY:
-		e_scroll_frame_set_policy (sf, g_value_get_enum (value), priv->vsb_policy);
+	case ARG_HSCROLLBAR_POLICY:
+		e_scroll_frame_set_policy (sf, GTK_VALUE_INT (*arg), priv->vsb_policy);
 		break;
 
-	case PROP_VSCROLLBAR_POLICY:
-		e_scroll_frame_set_policy (sf, priv->hsb_policy, g_value_get_enum (value));
+	case ARG_VSCROLLBAR_POLICY:
+		e_scroll_frame_set_policy (sf, priv->hsb_policy, GTK_VALUE_INT (*arg));
 		break;
 
-	case PROP_FRAME_PLACEMENT:
-		e_scroll_frame_set_placement (sf, g_value_get_enum (value));
+	case ARG_FRAME_PLACEMENT:
+		e_scroll_frame_set_placement (sf, GTK_VALUE_INT (*arg));
 		break;
 
-	case PROP_SHADOW_TYPE:
-		e_scroll_frame_set_shadow_type (sf, g_value_get_enum (value));
+	case ARG_SHADOW_TYPE:
+		e_scroll_frame_set_shadow_type (sf, GTK_VALUE_INT (*arg));
 		break;
 
-	case PROP_SCROLLBAR_SPACING:
-		e_scroll_frame_set_scrollbar_spacing (sf, g_value_get_uint (value));
+	case ARG_SCROLLBAR_SPACING:
+		e_scroll_frame_set_scrollbar_spacing (sf, GTK_VALUE_UINT (*arg));
 		break;
 
 	default:
@@ -305,7 +296,7 @@ e_scroll_frame_set_property (GObject *object, guint prop_id, const GValue *value
 
 /* Get_arg handler for the scroll frame widget */
 static void
-e_scroll_frame_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+e_scroll_frame_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	EScrollFrame *sf;
 	ScrollFramePrivate *priv;
@@ -313,44 +304,44 @@ e_scroll_frame_get_property (GObject *object, guint prop_id, GValue *value, GPar
 	sf = E_SCROLL_FRAME (object);
 	priv = sf->priv;
 
-	switch (prop_id) {
-	case PROP_HADJUSTMENT:
-		g_value_set_object (value, e_scroll_frame_get_hadjustment (sf));
+	switch (arg_id) {
+	case ARG_HADJUSTMENT:
+		GTK_VALUE_POINTER (*arg) = e_scroll_frame_get_hadjustment (sf);
 		break;
 
-	case PROP_VADJUSTMENT:
-		g_value_set_object (value, e_scroll_frame_get_vadjustment (sf));
+	case ARG_VADJUSTMENT:
+		GTK_VALUE_POINTER (*arg) = e_scroll_frame_get_vadjustment (sf);
 		break;
 
-	case PROP_HSCROLLBAR_POLICY:
-		g_value_set_enum (value, priv->hsb_policy);
+	case ARG_HSCROLLBAR_POLICY:
+		GTK_VALUE_INT (*arg) = priv->hsb_policy;
 		break;
 
-	case PROP_VSCROLLBAR_POLICY:
-		g_value_set_enum (value, priv->vsb_policy);
+	case ARG_VSCROLLBAR_POLICY:
+		GTK_VALUE_INT (*arg) = priv->vsb_policy;
 		break;
 
-	case PROP_FRAME_PLACEMENT:
-		g_value_set_enum (value, priv->frame_placement);
+	case ARG_FRAME_PLACEMENT:
+		GTK_VALUE_INT (*arg) = priv->frame_placement;
 		break;
 
-	case PROP_SHADOW_TYPE:
-		g_value_set_enum (value, priv->shadow_type);
+	case ARG_SHADOW_TYPE:
+		GTK_VALUE_INT (*arg) = priv->shadow_type;
 		break;
 
-	case PROP_SCROLLBAR_SPACING:
-		g_value_set_uint (value, priv->sb_spacing);
+	case ARG_SCROLLBAR_SPACING:
+		GTK_VALUE_UINT (*arg) = priv->sb_spacing;
 		break;
 
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		arg->type = GTK_TYPE_INVALID;
 		break;
 	}
 }
 
 /* Destroy handler for the scroll frame widget */
 static void
-e_scroll_frame_dispose (GObject *object)
+e_scroll_frame_destroy (GtkObject *object)
 {
 	EScrollFrame *sf;
 	ScrollFramePrivate *priv;
@@ -361,20 +352,14 @@ e_scroll_frame_dispose (GObject *object)
 	sf = E_SCROLL_FRAME (object);
 	priv = sf->priv;
 
-	if (priv->hsb) {
-		gtk_widget_unparent (priv->hsb);
-		gtk_widget_destroy (priv->hsb);
-		priv->hsb = NULL;
-	}
+	gtk_widget_unparent (priv->hsb);
+	gtk_widget_unparent (priv->vsb);
 
-	if (priv->vsb) {
-		gtk_widget_unparent (priv->vsb);
-		gtk_widget_destroy (priv->vsb);
-		priv->vsb = NULL;
-	}
+	gtk_widget_destroy (priv->hsb);
+	gtk_widget_destroy (priv->vsb);
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		(* G_OBJECT_CLASS (parent_class)->dispose) (object);
+	if (GTK_OBJECT_CLASS (parent_class)->destroy)
+		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 /* Finalize handler for the scroll frame widget */
@@ -387,6 +372,9 @@ e_scroll_frame_finalize (GObject *object)
 	sf = E_SCROLL_FRAME (object);
 	priv = sf->priv;
 
+	gtk_widget_unref (priv->hsb);
+	gtk_widget_unref (priv->vsb);
+
 	g_free (priv);
 
 	if (G_OBJECT_CLASS (parent_class)->finalize)
@@ -560,7 +548,7 @@ e_scroll_frame_size_request (GtkWidget *widget, GtkRequisition *requisition)
 	gtk_widget_size_request (priv->vsb, &vsb_requisition);
 
 	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		static GQuark quark_aux_info;
+		static guint quark_aux_info;
 
 		if (!quark_aux_info)
 			quark_aux_info = g_quark_from_static_string ("gtk-aux-info");
@@ -572,8 +560,8 @@ e_scroll_frame_size_request (GtkWidget *widget, GtkRequisition *requisition)
 		else {
 			GtkWidgetAuxInfo *aux_info;
 
-			aux_info = g_object_get_qdata (G_OBJECT (bin->child),
-						       quark_aux_info);
+			aux_info = gtk_object_get_data_by_id (GTK_OBJECT (bin->child),
+							      quark_aux_info);
 			if (aux_info && aux_info->width > 0) {
 				requisition->width += aux_info->width;
 				extra_width = -1;
@@ -586,8 +574,8 @@ e_scroll_frame_size_request (GtkWidget *widget, GtkRequisition *requisition)
 		else {
 			GtkWidgetAuxInfo *aux_info;
 
-			aux_info = g_object_get_qdata (G_OBJECT (bin->child),
-						       quark_aux_info);
+			aux_info = gtk_object_get_data_by_id (GTK_OBJECT (bin->child),
+							      quark_aux_info);
 			if (aux_info && aux_info->height > 0) {
 				requisition->height += aux_info->height;
 				extra_height = -1;
@@ -807,11 +795,11 @@ e_scroll_frame_button_press (GtkWidget *widget, GdkEventButton *event)
 		GtkAdjustment *adj;
 		gfloat new_value;
 
-		g_object_get (widget,
-			      (event->state & GDK_CONTROL_MASK) ?
-			      "hadjustment" : "vadjustment", 
-			      &adj,
-			      NULL);
+		gtk_object_get (GTK_OBJECT (widget),
+				(event->state & GDK_CONTROL_MASK) ?
+				 "hadjustment" : "vadjustment", 
+				 &adj,
+				NULL);
 		new_value = adj->value + ((event->button == 4) ? 
 					  -adj->page_increment / 2: 
 					  adj->page_increment / 2);
@@ -981,7 +969,7 @@ e_scroll_frame_set_hadjustment (EScrollFrame *sf, GtkAdjustment *adj)
 	if (adj)
 		g_return_if_fail (GTK_IS_ADJUSTMENT (adj));
 	else
-		adj = GTK_ADJUSTMENT (g_object_new (GTK_TYPE_ADJUSTMENT, NULL));
+		adj = GTK_ADJUSTMENT (gtk_object_new (GTK_TYPE_ADJUSTMENT, NULL));
 
 	if (!priv->hsb) {
 		gtk_widget_push_composite_child ();
@@ -999,19 +987,17 @@ e_scroll_frame_set_hadjustment (EScrollFrame *sf, GtkAdjustment *adj)
 		if (old_adj == adj)
 			return;
 
-		g_signal_handlers_disconnect_matched (old_adj,
-						      G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
-						      0, 0, NULL,
-						      adjustment_changed,
-						      sf);
+		gtk_signal_disconnect_by_func (GTK_OBJECT (old_adj),
+					       GTK_SIGNAL_FUNC (adjustment_changed),
+					       sf);
 		gtk_range_set_adjustment (GTK_RANGE (priv->hsb), adj);
 	}
 
 	adj = gtk_range_get_adjustment (GTK_RANGE (priv->hsb));
-	g_signal_connect (adj,
-			  "changed",
-			  G_CALLBACK (adjustment_changed),
-			  sf);
+	gtk_signal_connect (GTK_OBJECT (adj),
+			    "changed",
+			    GTK_SIGNAL_FUNC (adjustment_changed),
+			    sf);
 	adjustment_changed (adj, sf);
 
 	if (GTK_BIN (sf)->child)
@@ -1042,7 +1028,7 @@ e_scroll_frame_set_vadjustment (EScrollFrame *sf, GtkAdjustment *adj)
 	if (adj)
 		g_return_if_fail (GTK_IS_ADJUSTMENT (adj));
 	else
-		adj = GTK_ADJUSTMENT (g_object_new (GTK_TYPE_ADJUSTMENT, NULL));
+		adj = GTK_ADJUSTMENT (gtk_object_new (GTK_TYPE_ADJUSTMENT, NULL));
 
 	if (!priv->vsb) {
 		gtk_widget_push_composite_child ();
@@ -1060,19 +1046,17 @@ e_scroll_frame_set_vadjustment (EScrollFrame *sf, GtkAdjustment *adj)
 		if (old_adj == adj)
 			return;
 
-		g_signal_handlers_disconnect_matched (old_adj,
-						      G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
-						      0, 0, NULL,
-						      adjustment_changed,
-						      sf);
+		gtk_signal_disconnect_by_func (GTK_OBJECT (old_adj),
+					       GTK_SIGNAL_FUNC (adjustment_changed),
+					       sf);
 		gtk_range_set_adjustment (GTK_RANGE (priv->vsb), adj);
 	}
 
 	adj = gtk_range_get_adjustment (GTK_RANGE (priv->vsb));
-	g_signal_connect (adj,
-			  "changed",
-			  G_CALLBACK (adjustment_changed),
-			  sf);
+	gtk_signal_connect (GTK_OBJECT (adj),
+			    "changed",
+			    GTK_SIGNAL_FUNC (adjustment_changed),
+			    sf);
 	adjustment_changed (adj, sf);
 
 	if (GTK_BIN (sf)->child)
