@@ -43,10 +43,6 @@
 #include <stdlib.h>
 #include "gal/util/e-iconv.h"
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
 #define d(x) x
 
 #define FONT_TESTING
@@ -55,9 +51,7 @@
 static gint e_canonical_decomposition (gunichar ch, gunichar * buf);
 static gunichar e_stripped_char (gunichar ch);
 
-#ifndef NO_WARNINGS
 #warning FIXME: this has not been ported fully yet - non ASCII people beware.
-#endif
 
 /*
  * This my favourite
@@ -112,7 +106,7 @@ e_utf8_strstrcasedecomp (const gchar *haystack, const gchar *needle)
 					npos++;
 				}
 				if (npos == nlen) {
-					return o;
+					return p;
 				}
 			}
 		}
@@ -160,7 +154,7 @@ e_utf8_strstrcase (const gchar *haystack, const gchar *needle)
 				npos++;
 			}
 			if (npos == nlen) {
-				return o;
+				return p;
 			}
 		}
 		o = p;
@@ -221,8 +215,8 @@ e_utf8_from_gtk_event_key (GtkWidget *widget, guint keyval, const gchar *string)
 	gint unilen;
 
 	if (keyval == GDK_VoidSymbol) {
-		utf = e_utf8_from_locale_string (string);
-	} else {
+			utf = e_utf8_from_locale_string (string);
+		} else {
 		unival = gdk_keyval_to_unicode (keyval);
 
 		if (unival < ' ') return NULL;
@@ -261,7 +255,7 @@ e_utf8_from_iconv_string_sized (iconv_t ic, const gchar *string, gint bytes)
 	ib = string;
 	ibl = bytes;
 	new = ob = g_new (gchar, ibl * 6 + 1);
-	obl = ibl * 6;
+	obl = ibl * 6 + 1;
 
 	while (ibl > 0) {
 		e_iconv (ic, &ib, &ibl, &ob, &obl);
@@ -323,9 +317,9 @@ e_utf8_to_iconv_string_sized (iconv_t ic, const gchar *string, gint bytes)
 
 	ib = string;
 	ibl = bytes;
-	new = ob = g_new (char, ibl * 4 + 4);
-	obl = ibl * 4;
-	
+	new = ob = g_new (gchar, ibl * 4 + 1);
+	obl = ibl * 4 + 1;
+
 	while (ibl > 0) {
 		e_iconv (ic, &ib, &ibl, &ob, &obl);
 		if (ibl > 0) {
@@ -341,16 +335,13 @@ e_utf8_to_iconv_string_sized (iconv_t ic, const gchar *string, gint bytes)
 			ib += len;
 			ibl = bytes - (ib - string);
 			if (ibl > bytes) ibl = 0;
-			
-			/* FIXME: this is wrong... what if the destination charset is 16 or 32 bit? */
 			*ob++ = '_';
 			obl--;
 		}
 	}
-	
-	/* Make sure to terminate with plenty of padding */
-	memset (ob, 0, 4);
-	
+
+	*ob = '\0';
+
 	return new;
 }
 
@@ -453,7 +444,7 @@ e_utf8_from_gtk_string_sized (GtkWidget *widget, const gchar *string, gint bytes
 	ib = string;
 	ibl = bytes;
 	new = ob = g_new (gchar, ibl * 6 + 1);
-	obl = ibl * 6;
+	obl = ibl * 6 + 1;
 
 	while (ibl > 0) {
 		e_iconv (ic, &ib, &ibl, &ob, &obl);
@@ -513,7 +504,7 @@ e_utf8_to_gtk_string_sized (GtkWidget *widget, const gchar *string, gint bytes)
 		xfs = GDK_FONT_XFONT (gtk_style_get_font (widget->style));
 		twobyte = (gtk_style_get_font (widget->style)->type == GDK_FONT_FONTSET || ((xfs->min_byte1 != 0) || (xfs->max_byte1 != 0)));
 
-		new = g_new (unsigned char, bytes * 4 + 2);
+		new = g_new (unsigned char, bytes * 4 + 1);
 		u = string;
 		len = 0;
 
@@ -524,18 +515,14 @@ e_utf8_to_gtk_string_sized (GtkWidget *widget, const gchar *string, gint bytes)
 			}
 			new[len++] = uc & 0xff;
 		}
-		
-		new[len++] = '\0';
-		if (twobyte)
-			new[len] = '\0';
-		
+		new[len] = '\0';
 		return new;
 	}
 
 	ib = string;
 	ibl = bytes;
-	new = ob = g_new (gchar, ibl * 4 + 4);
-	obl = ibl * 4;
+	new = ob = g_new (gchar, ibl * 4 + 1);
+	obl = ibl * 4 + 1;
 
 	while (ibl > 0) {
 		e_iconv (ic, &ib, &ibl, &ob, &obl);
@@ -556,12 +543,11 @@ e_utf8_to_gtk_string_sized (GtkWidget *widget, const gchar *string, gint bytes)
 			obl--;
 		}
 	}
-	
-	/* Make sure to terminate with plenty of padding */
-	memset (ob, 0, 4);
-	
+
+	*ob = '\0';
+
 	e_iconv_close(ic);
-	
+
 	return new;
 }
 
@@ -2263,7 +2249,7 @@ e_xml_get_translated_utf8_string_prop_by_name (const xmlNode *parent, const xmlC
 	combined_name = g_strdup_printf("_%s", prop_name);
 	prop = xmlGetProp ((xmlNode *) parent, combined_name);
 	if (prop != NULL) {
-		ret_val = g_strdup (gettext (prop));
+		ret_val = e_utf8_from_locale_string (gettext (prop));
 		xmlFree (prop);
 	}
 	g_free(combined_name);
