@@ -45,9 +45,8 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint color_combo_signals [LAST_SIGNAL] = { 0, };
+static gint color_combo_signals [LAST_SIGNAL] = { 0, };
 
-#define PARENT_TYPE GTK_COMBO_BOX_TYPE
 static GObjectClass *color_combo_parent_class;
 
 #define make_color(CC,COL) (((COL) != NULL) ? (COL) : ((CC) ? ((CC)->default_color) : NULL))
@@ -69,56 +68,82 @@ color_combo_set_color_internal (ColorCombo *cc, GdkColor *color)
 }
 
 static void
-color_combo_class_init (GObjectClass *object_class)
+color_combo_finalize (GObject *object)
 {
-	color_combo_parent_class = g_type_class_ref (PARENT_TYPE);
-
-	color_combo_signals [CHANGED] =
-		g_signal_new ("color_changed",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ColorComboClass, color_changed),
-			      NULL, NULL,
-			      e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN_BOOLEAN,
-			      G_TYPE_NONE, 4, G_TYPE_POINTER,
-			      G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+	color_combo_parent_class->finalize (object);
 }
 
-E_MAKE_TYPE (color_combo,
-	     "ColorCombo",
-	     ColorCombo,
-	     color_combo_class_init,
-	     NULL,
-	     PARENT_TYPE)
+static void
+color_combo_class_init (GObjectClass *object_class)
+{
+	object_class->finalize = color_combo_finalize;
+
+	color_combo_parent_class = gtk_type_class (gtk_combo_box_get_type ());
+
+	color_combo_signals [CHANGED] =
+		gtk_signal_new (
+			"changed",
+			GTK_RUN_LAST,
+			E_OBJECT_CLASS_TYPE (object_class),
+			GTK_SIGNAL_OFFSET (ColorComboClass, changed),
+			e_marshal_NONE__POINTER_BOOLEAN,
+			GTK_TYPE_NONE, 2, GTK_TYPE_POINTER, GTK_TYPE_BOOL);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, color_combo_signals, LAST_SIGNAL);
+}
+
+GtkType
+color_combo_get_type (void)
+{
+	static GtkType type = 0;
+
+	if (!type){
+		GtkTypeInfo info = {
+			"ColorCombo",
+			sizeof (ColorCombo),
+			sizeof (ColorComboClass),
+			(GtkClassInitFunc) color_combo_class_init,
+			(GtkObjectInitFunc) NULL,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		type = gtk_type_unique (gtk_combo_box_get_type (), &info);
+	}
+
+	return type;
+}
 
 /*
- * Fires signal "color_changed" with the current color as its param
+ * Fires signal "changed" with the current color as its param
  */
 static void
-emit_color_changed (ColorCombo *cc, GdkColor *color,
-		    gboolean is_custom, gboolean by_user, gboolean is_default)
+emit_change (ColorCombo *cc, GdkColor *color, gboolean by_user)
 {
-  	g_signal_emit (cc,
-		       color_combo_signals [CHANGED], 0,
-		       color, is_custom, by_user, is_default);
+  	gtk_signal_emit (
+		GTK_OBJECT (cc),
+		color_combo_signals [CHANGED],
+		color, by_user);
 	gtk_combo_box_popup_hide (GTK_COMBO_BOX (cc));
 }
 
 static void
-cb_palette_color_changed (ColorPalette *P, GdkColor *color,
-		 gboolean custom, gboolean by_user, gboolean is_default,
+cb_color_change (ColorPalette *P, GdkColor *color,
+		 gboolean custom, gboolean by_user,
 		 ColorCombo *cc)
 {
 	color_combo_set_color_internal (cc, color);
-	emit_color_changed (cc, color, custom, by_user, is_default);
+		
+	emit_change (cc, color, by_user);
 }
 
 static void
 preview_clicked (GtkWidget *button, ColorCombo *cc)
 {
-	gboolean is_default;
-	GdkColor *color = color_palette_get_current_color (cc->palette, &is_default);
-	emit_color_changed (cc, color, FALSE, TRUE, is_default);
+	GdkColor *color = color_palette_get_current_color (cc->palette);
+	emit_change (cc, color, TRUE);
+	
 	if (color)
 		gdk_color_free (color);
 }
@@ -139,34 +164,25 @@ color_table_setup (ColorCombo *cc,
 	g_return_if_fail (cc != NULL);
 
 	/* Tell the palette that we will be changing it's custom colors */
-	cc->palette =
-		COLOR_PALETTE (color_palette_new (no_color_label,
+	cc->palette = 
+		COLOR_PALETTE (color_palette_new (no_color_label, 
 						  cc->default_color,
 						  color_group));
 
 	{
 		GtkWidget *picker = color_palette_get_color_picker (cc->palette);
-		g_signal_connect (picker, "clicked",
-				  G_CALLBACK (cb_cust_color_clicked), cc);
+		gtk_signal_connect (GTK_OBJECT (picker), "clicked",
+				    GTK_SIGNAL_FUNC (cb_cust_color_clicked), cc);
 	}
-
-	g_signal_connect (cc->palette, "color_changed",
-			  G_CALLBACK (cb_palette_color_changed), cc);
+	
+	gtk_signal_connect (GTK_OBJECT (cc->palette), "changed",
+			    GTK_SIGNAL_FUNC (cb_color_change), cc);
 
 	gtk_widget_show_all (GTK_WIDGET (cc->palette));
 
 	return;
 }
 
-void
-color_combo_box_set_preview_relief (ColorCombo *cc, GtkReliefStyle relief)
-{
-	g_return_if_fail (cc != NULL);
-	g_return_if_fail (IS_COLOR_COMBO (cc));
-
-	gtk_button_set_relief (GTK_BUTTON (cc->preview_button), relief);
-}
-
 /*
  * Where the actual construction goes on
  */
@@ -175,7 +191,6 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
 		       char const *no_color_label,
 		       ColorGroup *color_group)
 {
-	GdkColor *color;
 	g_return_if_fail (cc != NULL);
 	g_return_if_fail (IS_COLOR_COMBO (cc));
 
@@ -197,8 +212,7 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
 			"y",      0.0,
 			"anchor", GTK_ANCHOR_NW,
 			NULL);
-		gdk_pixbuf_unref (icon);
-
+		
 		cc->preview_color_item = gnome_canvas_item_new (
 			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
 			gnome_canvas_rect_get_type (),
@@ -220,23 +234,25 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
 			"fill_color", "black",
 			"width_pixels", 1,
 			NULL);
-
+	
 	gtk_container_add (GTK_CONTAINER (cc->preview_button), GTK_WIDGET (cc->preview_canvas));
-	gtk_widget_set_usize (GTK_WIDGET (cc->preview_canvas), 24, 22);
-	g_signal_connect (cc->preview_button, "clicked",
-			  G_CALLBACK (preview_clicked), cc);
-
+	gtk_widget_set_usize (GTK_WIDGET (cc->preview_canvas), 24, 24);
+	gtk_signal_connect (GTK_OBJECT (cc->preview_button), "clicked",
+			    GTK_SIGNAL_FUNC (preview_clicked), cc);
+	
+	/*
+	 * Our table selector
+	 */
 	color_table_setup (cc, no_color_label, color_group);
-
+	
 	gtk_widget_show_all (cc->preview_button);
-
+	
 	gtk_combo_box_construct (GTK_COMBO_BOX (cc),
 				 cc->preview_button,
 				 GTK_WIDGET (cc->palette));
 
-	color = color_palette_get_current_color (cc->palette, NULL);
-	color_combo_set_color_internal (cc, color);
-	if (color) gdk_color_free (color);
+	/* Set our color to the current color on the palette */
+	color_combo_set_color_internal (cc, color_palette_get_current_color (cc->palette));
 }
 
 /* color_combo_get_color:
@@ -244,61 +260,38 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
  * Return current color, result must be freed with gdk_color_free !
  */
 GdkColor *
-color_combo_get_color (ColorCombo *cc, gboolean *is_default)
+color_combo_get_color (ColorCombo *cc)
 {
-	return color_palette_get_current_color (cc->palette, is_default);
+	return color_palette_get_current_color (cc->palette);
 }
 
-/**
- * color_combo_set_color
- * @cc     The combo
- * @color  The color
- *
- * Set the color of the combo to the given color. Causes the color_changed
- * signal to be emitted.
- */
 void
 color_combo_set_color (ColorCombo *cc, GdkColor *color)
 {
-	/* This will change the color on the palette than it will invoke
-	 * cb_palette_color_changed which will call emit_color_changed and
-	 * set_color_internal which will change the color on our preview and
-	 * will let the users of the combo know that the current color has
-	 * changed
+	/* This will change the color on the palette than
+	 * it will invoke cb_color_change which will call emit_change
+	 * and set_color_internal which will change the color on
+	 * our preview and will let the users of the combo know
+	 * that the current color has changed
 	 */
-	if (color != NULL)
-		gdk_rgb_find_color (gtk_widget_get_colormap (GTK_WIDGET (cc)), color);
 	color_palette_set_current_color (cc->palette, color);
 }
 
-/**
- * color_combo_set_color_to_default
- * @cc  The combo
- *
- * Set the color of the combo to the default color. Causes the color_changed
- * signal to be emitted.
- */
-void
-color_combo_set_color_to_default (ColorCombo *cc)
-{
-	color_palette_set_color_to_default (cc->palette);
-}
-
 /**
  * color_combo_new :
  * icon : optionally NULL.
  * , const char *no_color_label,
- * Default constructor. Pass an optional icon and an optional label for the
- * no/auto color button.
+ * Default constructor. Pass an XPM icon and an optional label for
+ * the no/auto color button.
  */
 GtkWidget *
 color_combo_new (GdkPixbuf *icon, char const *no_color_label,
 		 GdkColor *default_color,
-		 ColorGroup *color_group)
+		 ColorGroup  *color_group)
 {
 	ColorCombo *cc;
 
-	cc = g_object_new (COLOR_COMBO_TYPE, NULL);
+	cc = gtk_type_new (color_combo_get_type ());
 
         cc->default_color = default_color;
 
