@@ -38,9 +38,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint pixmap_combo_signals [LAST_SIGNAL] = { 0, };
-
-#define PARENT_TYPE GTK_COMBO_BOX_TYPE
+static gint pixmap_combo_signals [LAST_SIGNAL] = { 0, };
 static GtkObjectClass *pixmap_combo_parent_class;
 
 /***************************************************************************/
@@ -51,9 +49,12 @@ pixmap_combo_destroy (GtkObject *object)
 	PixmapCombo *pc = PIXMAP_COMBO (object);
 
 	if (pc->tool_tip)
-		g_object_unref (pc->tool_tip);
+		gtk_object_unref (GTK_OBJECT (pc->tool_tip));
 	pc->tool_tip = NULL;
 	
+	g_free (pc->pixmaps);
+	pc->pixmaps = NULL;
+
 	(*pixmap_combo_parent_class->destroy) (object);
 }
 
@@ -62,24 +63,42 @@ pixmap_combo_class_init (GtkObjectClass *object_class)
 {
 	object_class->destroy = pixmap_combo_destroy;
 
-	pixmap_combo_parent_class = g_type_class_ref (PARENT_TYPE);
+	pixmap_combo_parent_class = gtk_type_class (gtk_combo_box_get_type ());
 
 	pixmap_combo_signals [CHANGED] =
-		g_signal_new ("changed",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (PixmapComboClass, changed),
-			      NULL, NULL,
-			      e_marshal_NONE__INT,
-			      G_TYPE_NONE, 1, G_TYPE_INT);
+		gtk_signal_new (
+			"changed",
+			GTK_RUN_LAST,
+			E_OBJECT_CLASS_TYPE (object_class),
+			GTK_SIGNAL_OFFSET (PixmapComboClass, changed),
+			gtk_marshal_NONE__INT,
+			GTK_TYPE_NONE, 1, GTK_TYPE_INT);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, pixmap_combo_signals, LAST_SIGNAL);
 }
 
-E_MAKE_TYPE (pixmap_combo,
-	     "PixmapCombo",
-	     PixmapCombo,
-	     pixmap_combo_class_init,
-	     NULL,
-	     PARENT_TYPE)
+GtkType
+pixmap_combo_get_type (void)
+{
+	static GtkType type = 0;
+
+	if (!type){
+		GtkTypeInfo info = {
+			"PixmapCombo",
+			sizeof (PixmapCombo),
+			sizeof (PixmapComboClass),
+			(GtkClassInitFunc) pixmap_combo_class_init,
+			(GtkObjectInitFunc) NULL,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		type = gtk_type_unique (gtk_combo_box_get_type (), &info);
+	}
+
+	return type;
+}
 
 static void
 emit_change (GtkWidget *button, PixmapCombo *pc)
@@ -88,8 +107,8 @@ emit_change (GtkWidget *button, PixmapCombo *pc)
 	g_return_if_fail (0 <= pc->last_index);
 	g_return_if_fail (pc->last_index < pc->num_elements);
 
-	g_signal_emit (pc, pixmap_combo_signals [CHANGED], 0,
-		       pc->elements[pc->last_index].index);
+	gtk_signal_emit (GTK_OBJECT (pc), pixmap_combo_signals [CHANGED],
+			 pc->elements[pc->last_index].index);
 }
 
 static void
@@ -101,15 +120,6 @@ pixmap_clicked (GtkWidget *button, PixmapCombo *pc)
 	gtk_combo_box_popup_hide (GTK_COMBO_BOX (pc));
 }
 
-static GtkWidget *
-image_from_data (guint8 const *data)
-{
-	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1,  data, FALSE, NULL);
-	GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
-	g_object_unref (pixbuf);
-	return image;
-}
-
 static void
 pixmap_table_setup (PixmapCombo *pc)
 {
@@ -117,9 +127,11 @@ pixmap_table_setup (PixmapCombo *pc)
 
 	pc->combo_table = gtk_table_new (pc->cols, pc->rows, 0);
 	pc->tool_tip = gtk_tooltips_new ();
-	g_object_ref (pc->tool_tip);
+	gtk_object_ref (GTK_OBJECT (pc->tool_tip));
 	gtk_object_sink (GTK_OBJECT (pc->tool_tip));
 
+	pc->pixmaps = g_malloc (sizeof (GtkWidget *) * pc->cols * pc->rows);
+
 	for (row = 0; row < pc->rows; row++) {
 		for (col = 0; col < pc->cols; ++col, ++index) {
 			PixmapComboElement const *element = pc->elements + index;
@@ -131,21 +143,26 @@ pixmap_table_setup (PixmapCombo *pc)
 				break;
 			}
 
+			pc->pixmaps [index] = gtk_image_new_from_pixbuf (
+				gdk_pixbuf_new_from_inline (-1, 
+					element->inline_gdkpixbuf ,
+					FALSE, NULL));
+
 			button = gtk_button_new ();
-			gtk_container_add (GTK_CONTAINER (button),
-				image_from_data (element->inline_gdkpixbuf));
 			gtk_button_set_relief (GTK_BUTTON (button),
-				GTK_RELIEF_NONE);
+					       GTK_RELIEF_NONE);
+			gtk_container_add (GTK_CONTAINER (button),
+					   pc->pixmaps [index]);
 			gtk_tooltips_set_tip (pc->tool_tip,
-				button,
-				gettext (element->untranslated_tooltip),
-				"What goes here ??");
+					      button,
+					      gettext (element->untranslated_tooltip),
+					      "What goes here ??");
 
 			gtk_table_attach (GTK_TABLE (pc->combo_table), button,
 					  col, col+1, row+1, row+2, GTK_FILL, GTK_FILL, 1, 1);
 
-			g_signal_connect (button, "clicked",
-					  G_CALLBACK (pixmap_clicked), pc);
+			gtk_signal_connect (GTK_OBJECT (button), "clicked",
+					    GTK_SIGNAL_FUNC (pixmap_clicked), pc);
 			gtk_object_set_user_data (GTK_OBJECT (button),
 						  GINT_TO_POINTER (index));
 		}
@@ -171,12 +188,14 @@ pixmap_combo_construct (PixmapCombo *pc,
 	pc->preview_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (pc->preview_button), GTK_RELIEF_NONE);
 
-	pc->preview_pixmap = image_from_data (elements [0].inline_gdkpixbuf);
+	pc->preview_pixmap = gtk_image_new_from_pixbuf (
+		gdk_pixbuf_new_from_inline (-1, 
+			elements [0].inline_gdkpixbuf , FALSE, NULL));
 
 	gtk_container_add (GTK_CONTAINER (pc->preview_button), GTK_WIDGET (pc->preview_pixmap));
 	gtk_widget_set_usize (GTK_WIDGET (pc->preview_pixmap), 24, 24);
-	g_signal_connect (pc->preview_button, "clicked",
-			  G_CALLBACK (emit_change), pc);
+	gtk_signal_connect (GTK_OBJECT (pc->preview_button), "clicked",
+			    GTK_SIGNAL_FUNC (emit_change), pc);
 
 	gtk_widget_show_all (pc->preview_button);
 
@@ -195,7 +214,7 @@ pixmap_combo_new (PixmapComboElement const *elements, int ncols, int nrows)
 	g_return_val_if_fail (ncols > 0, NULL);
 	g_return_val_if_fail (nrows > 0, NULL);
 
-	pc = g_object_new (PIXMAP_COMBO_TYPE, NULL);
+	pc = gtk_type_new (pixmap_combo_get_type ());
 
 	pixmap_combo_construct (pc, elements, ncols, nrows);
 
@@ -216,8 +235,9 @@ pixmap_combo_select_pixmap (PixmapCombo *pc, int index)
 		GTK_CONTAINER (pc->preview_button),
 		pc->preview_pixmap);
 
-	pc->preview_pixmap = image_from_data (
-		pc->elements [index].inline_gdkpixbuf);
+	pc->preview_pixmap = gtk_image_new_from_pixbuf (
+		gdk_pixbuf_new_from_inline (-1, 
+			pc->elements [index].inline_gdkpixbuf , FALSE, NULL));
 	gtk_widget_show (pc->preview_pixmap);
 	
 	gtk_container_add (
